aboutsummaryrefslogtreecommitdiffstats
path: root/common-logging
diff options
context:
space:
mode:
authorGuo Ruijing <ruijing.guo@intel.com>2017-07-28 08:21:14 +0000
committerPamela Dragosh <pdragosh@research.att.com>2017-07-31 08:31:07 -0400
commitf8a620d1ff2b0d33b08a22279058f3e0253bdde1 (patch)
tree9092df7a6c57a46d36988245f60db0c29a7b1404 /common-logging
parente7bd0934d383c811b0b7302c42991aa1d61941c4 (diff)
[POLICY-71] replace openecomp for policy-common
Change-Id: I3241f5d1f0234043b4dff718eda1ffdc48052276 Signed-off-by: Guo Ruijing <ruijing.guo@intel.com> Signed-off-by: Pamela Dragosh <pdragosh@research.att.com>
Diffstat (limited to 'common-logging')
-rw-r--r--common-logging/config/policyLogger.properties2
-rw-r--r--common-logging/policyLogger.properties2
-rw-r--r--common-logging/pom.xml14
-rw-r--r--common-logging/src/main/java/org/onap/policy/common/logging/ONAPLoggingContext.java (renamed from common-logging/src/main/java/org/openecomp/policy/common/logging/ECOMPLoggingContext.java)30
-rw-r--r--common-logging/src/main/java/org/onap/policy/common/logging/ONAPLoggingUtils.java (renamed from common-logging/src/main/java/org/openecomp/policy/common/logging/ECOMPLoggingUtils.java)14
-rw-r--r--common-logging/src/main/java/org/onap/policy/common/logging/eelf/Configuration.java (renamed from common-logging/src/main/java/org/openecomp/policy/common/logging/eelf/Configuration.java)4
-rw-r--r--common-logging/src/main/java/org/onap/policy/common/logging/eelf/DroolsPDPMDCInfo.java (renamed from common-logging/src/main/java/org/openecomp/policy/common/logging/eelf/DroolsPDPMDCInfo.java)22
-rw-r--r--common-logging/src/main/java/org/onap/policy/common/logging/eelf/ErrorCodeMap.java (renamed from common-logging/src/main/java/org/openecomp/policy/common/logging/eelf/ErrorCodeMap.java)4
-rw-r--r--common-logging/src/main/java/org/onap/policy/common/logging/eelf/EventData.java (renamed from common-logging/src/main/java/org/openecomp/policy/common/logging/eelf/EventData.java)4
-rw-r--r--common-logging/src/main/java/org/onap/policy/common/logging/eelf/EventTrackInfo.java (renamed from common-logging/src/main/java/org/openecomp/policy/common/logging/eelf/EventTrackInfo.java)4
-rw-r--r--common-logging/src/main/java/org/onap/policy/common/logging/eelf/EventTrackInfoHandler.java (renamed from common-logging/src/main/java/org/openecomp/policy/common/logging/eelf/EventTrackInfoHandler.java)4
-rw-r--r--common-logging/src/main/java/org/onap/policy/common/logging/eelf/MDCInfo.java (renamed from common-logging/src/main/java/org/openecomp/policy/common/logging/eelf/MDCInfo.java)4
-rw-r--r--common-logging/src/main/java/org/onap/policy/common/logging/eelf/MessageCodes.java (renamed from common-logging/src/main/java/org/openecomp/policy/common/logging/eelf/MessageCodes.java)6
-rw-r--r--common-logging/src/main/java/org/onap/policy/common/logging/eelf/PolicyLogger.java (renamed from common-logging/src/main/java/org/openecomp/policy/common/logging/eelf/PolicyLogger.java)10
-rw-r--r--common-logging/src/main/java/org/onap/policy/common/logging/flexlogger/EelfLogger.java (renamed from common-logging/src/main/java/org/openecomp/policy/common/logging/flexlogger/EelfLogger.java)10
-rw-r--r--common-logging/src/main/java/org/onap/policy/common/logging/flexlogger/FlexLogger.java (renamed from common-logging/src/main/java/org/openecomp/policy/common/logging/flexlogger/FlexLogger.java)8
-rw-r--r--common-logging/src/main/java/org/onap/policy/common/logging/flexlogger/FlexLoggerTester.java (renamed from common-logging/src/main/java/org/openecomp/policy/common/logging/flexlogger/FlexLoggerTester.java)4
-rw-r--r--common-logging/src/main/java/org/onap/policy/common/logging/flexlogger/Logger.java (renamed from common-logging/src/main/java/org/openecomp/policy/common/logging/flexlogger/Logger.java)6
-rw-r--r--common-logging/src/main/java/org/onap/policy/common/logging/flexlogger/Logger4J.java (renamed from common-logging/src/main/java/org/openecomp/policy/common/logging/flexlogger/Logger4J.java)10
-rw-r--r--common-logging/src/main/java/org/onap/policy/common/logging/flexlogger/LoggerType.java (renamed from common-logging/src/main/java/org/openecomp/policy/common/logging/flexlogger/LoggerType.java)4
-rw-r--r--common-logging/src/main/java/org/onap/policy/common/logging/flexlogger/PropertyUtil.java (renamed from common-logging/src/main/java/org/openecomp/policy/common/logging/flexlogger/PropertyUtil.java)4
-rw-r--r--common-logging/src/main/java/org/onap/policy/common/logging/flexlogger/SystemOutLogger.java (renamed from common-logging/src/main/java/org/openecomp/policy/common/logging/flexlogger/SystemOutLogger.java)8
-rw-r--r--common-logging/src/main/java/org/onap/policy/common/logging/nsa/LoggingContext.java (renamed from common-logging/src/main/java/org/openecomp/policy/common/logging/nsa/LoggingContext.java)4
-rw-r--r--common-logging/src/main/java/org/onap/policy/common/logging/nsa/LoggingContextFactory.java (renamed from common-logging/src/main/java/org/openecomp/policy/common/logging/nsa/LoggingContextFactory.java)8
-rw-r--r--common-logging/src/main/java/org/onap/policy/common/logging/nsa/SharedLoggingContext.java (renamed from common-logging/src/main/java/org/openecomp/policy/common/logging/nsa/SharedLoggingContext.java)4
-rw-r--r--common-logging/src/main/java/org/onap/policy/common/logging/nsa/impl/SharedContext.java (renamed from common-logging/src/main/java/org/openecomp/policy/common/logging/nsa/impl/SharedContext.java)8
-rw-r--r--common-logging/src/main/java/org/onap/policy/common/logging/nsa/impl/Slf4jLoggingContext.java (renamed from common-logging/src/main/java/org/openecomp/policy/common/logging/nsa/impl/Slf4jLoggingContext.java)6
-rw-r--r--common-logging/src/main/java/org/onap/policy/common/logging/nsa/package-info.java (renamed from common-logging/src/main/java/org/openecomp/policy/common/logging/nsa/package-info.java)4
-rw-r--r--common-logging/src/main/resources/org/onap/policy/common/logging/eelf/Resources.properties (renamed from common-logging/src/main/resources/org/openecomp/policy/common/logging/eelf/Resources.properties)2
29 files changed, 108 insertions, 106 deletions
diff --git a/common-logging/config/policyLogger.properties b/common-logging/config/policyLogger.properties
index 6aaa6a91..1feed375 100644
--- a/common-logging/config/policyLogger.properties
+++ b/common-logging/config/policyLogger.properties
@@ -1,6 +1,6 @@
###
# ============LICENSE_START=======================================================
-# ECOMP-Logging
+# ONAP-Logging
# ================================================================================
# Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
# ================================================================================
diff --git a/common-logging/policyLogger.properties b/common-logging/policyLogger.properties
index 7f160b6d..e2335df6 100644
--- a/common-logging/policyLogger.properties
+++ b/common-logging/policyLogger.properties
@@ -1,6 +1,6 @@
###
# ============LICENSE_START=======================================================
-# ECOMP-Logging
+# ONAP-Logging
# ================================================================================
# Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
# ================================================================================
diff --git a/common-logging/pom.xml b/common-logging/pom.xml
index 73810465..3352d4f6 100644
--- a/common-logging/pom.xml
+++ b/common-logging/pom.xml
@@ -1,6 +1,6 @@
<!--
============LICENSE_START=======================================================
- ECOMP Policy Engine - Common Modules
+ ONAP Policy Engine - Common Modules
================================================================================
Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
================================================================================
@@ -23,13 +23,13 @@
<modelVersion>4.0.0</modelVersion>
<parent>
- <groupId>org.openecomp.policy.common</groupId>
+ <groupId>org.onap.policy.common</groupId>
<artifactId>common-modules</artifactId>
<version>1.1.0-SNAPSHOT</version>
</parent>
- <artifactId>ECOMP-Logging</artifactId>
- <description>ECOMP Logging Framework</description>
+ <artifactId>ONAP-Logging</artifactId>
+ <description>ONAP Logging Framework</description>
<packaging>jar</packaging>
<dependencies>
@@ -75,8 +75,8 @@
<!-- We need to include the dependency of the project so that its include
in classpath when running plugin -->
<dependency>
- <groupId>org.openecomp.policy.common</groupId>
- <artifactId>ECOMP-Logging</artifactId>
+ <groupId>org.onap.policy.common</groupId>
+ <artifactId>ONAP-Logging</artifactId>
<version>${project.version}</version>
</dependency>
</dependencies>
@@ -85,7 +85,7 @@
<outputFile>messages.html</outputFile>
<resources>
<resource>
- <messageClass>org.openecomp.policy.common.logging.eelf.MessageCodes</messageClass>
+ <messageClass>org.onap.policy.common.logging.eelf.MessageCodes</messageClass>
This needs to be replaced with your Enum class name .which
implements EELFResolvableErrorEnum and have your defined error
codes.
diff --git a/common-logging/src/main/java/org/openecomp/policy/common/logging/ECOMPLoggingUtils.java b/common-logging/src/main/java/org/onap/policy/common/logging/ONAPLoggingUtils.java
index 5e6aa909..b4d4d8d2 100644
--- a/common-logging/src/main/java/org/openecomp/policy/common/logging/ECOMPLoggingUtils.java
+++ b/common-logging/src/main/java/org/onap/policy/common/logging/ONAPLoggingUtils.java
@@ -1,6 +1,6 @@
/*-
* ============LICENSE_START=======================================================
- * ECOMP-Logging
+ * ONAP-Logging
* ================================================================================
* Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
* ================================================================================
@@ -18,16 +18,16 @@
* ============LICENSE_END=========================================================
*/
-package org.openecomp.policy.common.logging;
+package org.onap.policy.common.logging;
import javax.servlet.http.HttpServletRequest;
-public class ECOMPLoggingUtils {
+public class ONAPLoggingUtils {
- public static ECOMPLoggingContext getLoggingContextForRequest(HttpServletRequest request,
- ECOMPLoggingContext baseContext)
+ public static ONAPLoggingContext getLoggingContextForRequest(HttpServletRequest request,
+ ONAPLoggingContext baseContext)
{
- ECOMPLoggingContext requestContext = new ECOMPLoggingContext(baseContext);
+ ONAPLoggingContext requestContext = new ONAPLoggingContext(baseContext);
if (request.getLocalAddr() != null) { // may be null in junit tests
requestContext.setServerIPAddress(request.getLocalAddr());
}
@@ -41,6 +41,8 @@ public class ECOMPLoggingUtils {
requestContext.setClientIPAddress(request.getRemoteAddr());
}
// RequestID
+ // This needs to be renamed to ONAP when the other components in ONAP
+ // rename to this.
String requestId = request.getHeader("X-ECOMP-RequestID");
if (requestId != null && requestId.trim().length() > 0) {
requestContext.setRequestID(requestId);
diff --git a/common-logging/src/main/java/org/openecomp/policy/common/logging/eelf/Configuration.java b/common-logging/src/main/java/org/onap/policy/common/logging/eelf/Configuration.java
index a839ea16..4cbe63af 100644
--- a/common-logging/src/main/java/org/openecomp/policy/common/logging/eelf/Configuration.java
+++ b/common-logging/src/main/java/org/onap/policy/common/logging/eelf/Configuration.java
@@ -1,6 +1,6 @@
/*-
* ============LICENSE_START=======================================================
- * ECOMP-Logging
+ * ONAP-Logging
* ================================================================================
* Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
* ================================================================================
@@ -18,7 +18,7 @@
* ============LICENSE_END=========================================================
*/
-package org.openecomp.policy.common.logging.eelf;
+package org.onap.policy.common.logging.eelf;
public interface Configuration extends com.att.eelf.configuration.Configuration{
diff --git a/common-logging/src/main/java/org/openecomp/policy/common/logging/eelf/DroolsPDPMDCInfo.java b/common-logging/src/main/java/org/onap/policy/common/logging/eelf/DroolsPDPMDCInfo.java
index ad502475..01fc0ddd 100644
--- a/common-logging/src/main/java/org/openecomp/policy/common/logging/eelf/DroolsPDPMDCInfo.java
+++ b/common-logging/src/main/java/org/onap/policy/common/logging/eelf/DroolsPDPMDCInfo.java
@@ -1,6 +1,6 @@
/*-
* ============LICENSE_START=======================================================
- * ECOMP-Logging
+ * ONAP-Logging
* ================================================================================
* Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
* ================================================================================
@@ -18,7 +18,7 @@
* ============LICENSE_END=========================================================
*/
-package org.openecomp.policy.common.logging.eelf;
+package org.onap.policy.common.logging.eelf;
import java.util.concurrent.ConcurrentHashMap;
@@ -28,15 +28,15 @@ public class DroolsPDPMDCInfo implements MDCInfo{
static {
- mdcMap.put(org.openecomp.policy.common.logging.eelf.Configuration.MDC_REMOTE_HOST, "");
- mdcMap.put(org.openecomp.policy.common.logging.eelf.Configuration.MDC_SERVICE_NAME, "Policy.droolsPdp");
- mdcMap.put(org.openecomp.policy.common.logging.eelf.Configuration.MDC_SERVICE_INSTANCE_ID, "Policy.droolsPdp.event");
- mdcMap.put(org.openecomp.policy.common.logging.eelf.Configuration.MDC_INSTANCE_UUID, "");
- mdcMap.put(org.openecomp.policy.common.logging.eelf.Configuration.MDC_ALERT_SEVERITY, "");
- mdcMap.put(org.openecomp.policy.common.logging.eelf.Configuration.PARTNER_NAME, "N/A");
- mdcMap.put(org.openecomp.policy.common.logging.eelf.Configuration.STATUS_CODE, "N/A");
- mdcMap.put(org.openecomp.policy.common.logging.eelf.Configuration.RESPONSE_CODE, "N/A");
- mdcMap.put(org.openecomp.policy.common.logging.eelf.Configuration.RESPONSE_DESCRIPTION, "N/A");
+ mdcMap.put(org.onap.policy.common.logging.eelf.Configuration.MDC_REMOTE_HOST, "");
+ mdcMap.put(org.onap.policy.common.logging.eelf.Configuration.MDC_SERVICE_NAME, "Policy.droolsPdp");
+ mdcMap.put(org.onap.policy.common.logging.eelf.Configuration.MDC_SERVICE_INSTANCE_ID, "Policy.droolsPdp.event");
+ mdcMap.put(org.onap.policy.common.logging.eelf.Configuration.MDC_INSTANCE_UUID, "");
+ mdcMap.put(org.onap.policy.common.logging.eelf.Configuration.MDC_ALERT_SEVERITY, "");
+ mdcMap.put(org.onap.policy.common.logging.eelf.Configuration.PARTNER_NAME, "N/A");
+ mdcMap.put(org.onap.policy.common.logging.eelf.Configuration.STATUS_CODE, "N/A");
+ mdcMap.put(org.onap.policy.common.logging.eelf.Configuration.RESPONSE_CODE, "N/A");
+ mdcMap.put(org.onap.policy.common.logging.eelf.Configuration.RESPONSE_DESCRIPTION, "N/A");
}
diff --git a/common-logging/src/main/java/org/openecomp/policy/common/logging/eelf/ErrorCodeMap.java b/common-logging/src/main/java/org/onap/policy/common/logging/eelf/ErrorCodeMap.java
index abd972e1..cbb8c7a3 100644
--- a/common-logging/src/main/java/org/openecomp/policy/common/logging/eelf/ErrorCodeMap.java
+++ b/common-logging/src/main/java/org/onap/policy/common/logging/eelf/ErrorCodeMap.java
@@ -1,6 +1,6 @@
/*-
* ============LICENSE_START=======================================================
- * ECOMP-Logging
+ * ONAP-Logging
* ================================================================================
* Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
* ================================================================================
@@ -18,7 +18,7 @@
* ============LICENSE_END=========================================================
*/
-package org.openecomp.policy.common.logging.eelf;
+package org.onap.policy.common.logging.eelf;
import java.util.HashMap;
diff --git a/common-logging/src/main/java/org/openecomp/policy/common/logging/eelf/EventData.java b/common-logging/src/main/java/org/onap/policy/common/logging/eelf/EventData.java
index d26a4977..2aaa1146 100644
--- a/common-logging/src/main/java/org/openecomp/policy/common/logging/eelf/EventData.java
+++ b/common-logging/src/main/java/org/onap/policy/common/logging/eelf/EventData.java
@@ -1,6 +1,6 @@
/*-
* ============LICENSE_START=======================================================
- * ECOMP-Logging
+ * ONAP-Logging
* ================================================================================
* Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
* ================================================================================
@@ -18,7 +18,7 @@
* ============LICENSE_END=========================================================
*/
-package org.openecomp.policy.common.logging.eelf;
+package org.onap.policy.common.logging.eelf;
import java.time.Instant;
diff --git a/common-logging/src/main/java/org/openecomp/policy/common/logging/eelf/EventTrackInfo.java b/common-logging/src/main/java/org/onap/policy/common/logging/eelf/EventTrackInfo.java
index f1b7afb5..7e4d45d8 100644
--- a/common-logging/src/main/java/org/openecomp/policy/common/logging/eelf/EventTrackInfo.java
+++ b/common-logging/src/main/java/org/onap/policy/common/logging/eelf/EventTrackInfo.java
@@ -1,6 +1,6 @@
/*-
* ============LICENSE_START=======================================================
- * ECOMP-Logging
+ * ONAP-Logging
* ================================================================================
* Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
* ================================================================================
@@ -18,7 +18,7 @@
* ============LICENSE_END=========================================================
*/
-package org.openecomp.policy.common.logging.eelf;
+package org.onap.policy.common.logging.eelf;
import java.util.concurrent.ConcurrentHashMap;
diff --git a/common-logging/src/main/java/org/openecomp/policy/common/logging/eelf/EventTrackInfoHandler.java b/common-logging/src/main/java/org/onap/policy/common/logging/eelf/EventTrackInfoHandler.java
index e45f8998..d0a7cc16 100644
--- a/common-logging/src/main/java/org/openecomp/policy/common/logging/eelf/EventTrackInfoHandler.java
+++ b/common-logging/src/main/java/org/onap/policy/common/logging/eelf/EventTrackInfoHandler.java
@@ -1,6 +1,6 @@
/*-
* ============LICENSE_START=======================================================
- * ECOMP-Logging
+ * ONAP-Logging
* ================================================================================
* Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
* ================================================================================
@@ -18,7 +18,7 @@
* ============LICENSE_END=========================================================
*/
-package org.openecomp.policy.common.logging.eelf;
+package org.onap.policy.common.logging.eelf;
import java.time.Duration;
import java.time.Instant;
diff --git a/common-logging/src/main/java/org/openecomp/policy/common/logging/eelf/MDCInfo.java b/common-logging/src/main/java/org/onap/policy/common/logging/eelf/MDCInfo.java
index 6b5e395f..fc44dcff 100644
--- a/common-logging/src/main/java/org/openecomp/policy/common/logging/eelf/MDCInfo.java
+++ b/common-logging/src/main/java/org/onap/policy/common/logging/eelf/MDCInfo.java
@@ -1,6 +1,6 @@
/*-
* ============LICENSE_START=======================================================
- * ECOMP-Logging
+ * ONAP-Logging
* ================================================================================
* Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
* ================================================================================
@@ -18,7 +18,7 @@
* ============LICENSE_END=========================================================
*/
-package org.openecomp.policy.common.logging.eelf;
+package org.onap.policy.common.logging.eelf;
import java.util.concurrent.ConcurrentHashMap;
diff --git a/common-logging/src/main/java/org/openecomp/policy/common/logging/eelf/MessageCodes.java b/common-logging/src/main/java/org/onap/policy/common/logging/eelf/MessageCodes.java
index 6f1437eb..a9920aec 100644
--- a/common-logging/src/main/java/org/openecomp/policy/common/logging/eelf/MessageCodes.java
+++ b/common-logging/src/main/java/org/onap/policy/common/logging/eelf/MessageCodes.java
@@ -1,6 +1,6 @@
/*-
* ============LICENSE_START=======================================================
- * ECOMP-Logging
+ * ONAP-Logging
* ================================================================================
* Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
* ================================================================================
@@ -18,7 +18,7 @@
* ============LICENSE_END=========================================================
*/
-package org.openecomp.policy.common.logging.eelf;
+package org.onap.policy.common.logging.eelf;
import com.att.eelf.i18n.EELFResolvableErrorEnum;
import com.att.eelf.i18n.EELFResourceManager;
@@ -152,7 +152,7 @@ public enum MessageCodes implements EELFResolvableErrorEnum {
* Here this application loads messages from three bundles
*/
static {
- EELFResourceManager.loadMessageBundle("org/openecomp/policy/common/logging/eelf/Resources");
+ EELFResourceManager.loadMessageBundle("org.onap.policy/common/logging/eelf/Resources");
String id = EELFResourceManager.getIdentifier(RULE_AUDIT_EXEC_INFO);
String value = EELFResourceManager.getMessage(RULE_AUDIT_EXEC_INFO);
diff --git a/common-logging/src/main/java/org/openecomp/policy/common/logging/eelf/PolicyLogger.java b/common-logging/src/main/java/org/onap/policy/common/logging/eelf/PolicyLogger.java
index 8cc73743..d0cc9c1e 100644
--- a/common-logging/src/main/java/org/openecomp/policy/common/logging/eelf/PolicyLogger.java
+++ b/common-logging/src/main/java/org/onap/policy/common/logging/eelf/PolicyLogger.java
@@ -1,6 +1,6 @@
/*-
* ============LICENSE_START=======================================================
- * ECOMP-Logging
+ * ONAP-Logging
* ================================================================================
* Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
* ================================================================================
@@ -18,14 +18,14 @@
* ============LICENSE_END=========================================================
*/
-package org.openecomp.policy.common.logging.eelf;
+package org.onap.policy.common.logging.eelf;
import org.slf4j.MDC;
-import static org.openecomp.policy.common.logging.eelf.Configuration.*;
+import static org.onap.policy.common.logging.eelf.Configuration.*;
-import org.openecomp.policy.common.logging.flexlogger.LoggerType;
-import org.openecomp.policy.common.logging.eelf.PolicyLogger;
+import org.onap.policy.common.logging.flexlogger.LoggerType;
+import org.onap.policy.common.logging.eelf.PolicyLogger;
import com.att.eelf.configuration.EELFLogger;
import com.att.eelf.configuration.EELFLogger.Level;
import com.att.eelf.configuration.EELFManager;
diff --git a/common-logging/src/main/java/org/openecomp/policy/common/logging/flexlogger/EelfLogger.java b/common-logging/src/main/java/org/onap/policy/common/logging/flexlogger/EelfLogger.java
index 106c734c..fbc0ae1d 100644
--- a/common-logging/src/main/java/org/openecomp/policy/common/logging/flexlogger/EelfLogger.java
+++ b/common-logging/src/main/java/org/onap/policy/common/logging/flexlogger/EelfLogger.java
@@ -1,6 +1,6 @@
/*-
* ============LICENSE_START=======================================================
- * ECOMP-Logging
+ * ONAP-Logging
* ================================================================================
* Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
* ================================================================================
@@ -18,14 +18,14 @@
* ============LICENSE_END=========================================================
*/
-package org.openecomp.policy.common.logging.flexlogger;
+package org.onap.policy.common.logging.flexlogger;
import java.io.Serializable;
import java.util.UUID;
-import org.openecomp.policy.common.logging.eelf.MessageCodes;
-import org.openecomp.policy.common.logging.eelf.PolicyLogger;
-import org.openecomp.policy.common.logging.flexlogger.Logger;
+import org.onap.policy.common.logging.eelf.MessageCodes;
+import org.onap.policy.common.logging.eelf.PolicyLogger;
+import org.onap.policy.common.logging.flexlogger.Logger;
import com.att.eelf.configuration.EELFLogger.Level;
/**
diff --git a/common-logging/src/main/java/org/openecomp/policy/common/logging/flexlogger/FlexLogger.java b/common-logging/src/main/java/org/onap/policy/common/logging/flexlogger/FlexLogger.java
index 3db40f1e..797f857b 100644
--- a/common-logging/src/main/java/org/openecomp/policy/common/logging/flexlogger/FlexLogger.java
+++ b/common-logging/src/main/java/org/onap/policy/common/logging/flexlogger/FlexLogger.java
@@ -1,6 +1,6 @@
/*-
* ============LICENSE_START=======================================================
- * ECOMP-Logging
+ * ONAP-Logging
* ================================================================================
* Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
* ================================================================================
@@ -18,7 +18,7 @@
* ============LICENSE_END=========================================================
*/
-package org.openecomp.policy.common.logging.flexlogger;
+package org.onap.policy.common.logging.flexlogger;
import java.io.IOException;
import java.text.SimpleDateFormat;
@@ -28,8 +28,8 @@ import java.util.Properties;
import java.util.Set;
import java.util.concurrent.ConcurrentHashMap;
-import org.openecomp.policy.common.logging.eelf.PolicyLogger;
-import org.openecomp.policy.common.logging.flexlogger.PropertyUtil.Listener;
+import org.onap.policy.common.logging.eelf.PolicyLogger;
+import org.onap.policy.common.logging.flexlogger.PropertyUtil.Listener;
/**
*
diff --git a/common-logging/src/main/java/org/openecomp/policy/common/logging/flexlogger/FlexLoggerTester.java b/common-logging/src/main/java/org/onap/policy/common/logging/flexlogger/FlexLoggerTester.java
index 3e0d558a..eddece12 100644
--- a/common-logging/src/main/java/org/openecomp/policy/common/logging/flexlogger/FlexLoggerTester.java
+++ b/common-logging/src/main/java/org/onap/policy/common/logging/flexlogger/FlexLoggerTester.java
@@ -1,6 +1,6 @@
/*-
* ============LICENSE_START=======================================================
- * ECOMP-Logging
+ * ONAP-Logging
* ================================================================================
* Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
* ================================================================================
@@ -18,7 +18,7 @@
* ============LICENSE_END=========================================================
*/
-package org.openecomp.policy.common.logging.flexlogger;
+package org.onap.policy.common.logging.flexlogger;
import java.util.UUID;
diff --git a/common-logging/src/main/java/org/openecomp/policy/common/logging/flexlogger/Logger.java b/common-logging/src/main/java/org/onap/policy/common/logging/flexlogger/Logger.java
index 8cfee16c..d3113d31 100644
--- a/common-logging/src/main/java/org/openecomp/policy/common/logging/flexlogger/Logger.java
+++ b/common-logging/src/main/java/org/onap/policy/common/logging/flexlogger/Logger.java
@@ -1,6 +1,6 @@
/*-
* ============LICENSE_START=======================================================
- * ECOMP-Logging
+ * ONAP-Logging
* ================================================================================
* Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
* ================================================================================
@@ -18,11 +18,11 @@
* ============LICENSE_END=========================================================
*/
-package org.openecomp.policy.common.logging.flexlogger;
+package org.onap.policy.common.logging.flexlogger;
import java.util.UUID;
-import org.openecomp.policy.common.logging.eelf.MessageCodes;
+import org.onap.policy.common.logging.eelf.MessageCodes;
/**
*
diff --git a/common-logging/src/main/java/org/openecomp/policy/common/logging/flexlogger/Logger4J.java b/common-logging/src/main/java/org/onap/policy/common/logging/flexlogger/Logger4J.java
index 506e1ea7..2e67a735 100644
--- a/common-logging/src/main/java/org/openecomp/policy/common/logging/flexlogger/Logger4J.java
+++ b/common-logging/src/main/java/org/onap/policy/common/logging/flexlogger/Logger4J.java
@@ -1,6 +1,6 @@
/*-
* ============LICENSE_START=======================================================
- * ECOMP-Logging
+ * ONAP-Logging
* ================================================================================
* Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
* ================================================================================
@@ -18,7 +18,7 @@
* ============LICENSE_END=========================================================
*/
-package org.openecomp.policy.common.logging.flexlogger;
+package org.onap.policy.common.logging.flexlogger;
import java.io.IOException;
import java.io.ObjectInputStream;
@@ -29,8 +29,8 @@ import java.util.UUID;
import org.apache.log4j.Logger;
import org.apache.log4j.Priority;
-import org.openecomp.policy.common.logging.eelf.MessageCodes;
-import org.openecomp.policy.common.logging.eelf.PolicyLogger;
+import org.onap.policy.common.logging.eelf.MessageCodes;
+import org.onap.policy.common.logging.eelf.PolicyLogger;
import com.att.eelf.configuration.EELFLogger.Level;
/**
@@ -38,7 +38,7 @@ import com.att.eelf.configuration.EELFLogger.Level;
* Logger4J implements all the methods of interface Logger by calling org.apache.log4j.Logger
*
*/
-public class Logger4J implements org.openecomp.policy.common.logging.flexlogger.Logger, Serializable {
+public class Logger4J implements org.onap.policy.common.logging.flexlogger.Logger, Serializable {
/**
*
diff --git a/common-logging/src/main/java/org/openecomp/policy/common/logging/flexlogger/LoggerType.java b/common-logging/src/main/java/org/onap/policy/common/logging/flexlogger/LoggerType.java
index 8fe55b29..ed2029e6 100644
--- a/common-logging/src/main/java/org/openecomp/policy/common/logging/flexlogger/LoggerType.java
+++ b/common-logging/src/main/java/org/onap/policy/common/logging/flexlogger/LoggerType.java
@@ -1,6 +1,6 @@
/*-
* ============LICENSE_START=======================================================
- * ECOMP-Logging
+ * ONAP-Logging
* ================================================================================
* Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
* ================================================================================
@@ -18,7 +18,7 @@
* ============LICENSE_END=========================================================
*/
-package org.openecomp.policy.common.logging.flexlogger;
+package org.onap.policy.common.logging.flexlogger;
/**
*
diff --git a/common-logging/src/main/java/org/openecomp/policy/common/logging/flexlogger/PropertyUtil.java b/common-logging/src/main/java/org/onap/policy/common/logging/flexlogger/PropertyUtil.java
index 462e10cb..598dd09b 100644
--- a/common-logging/src/main/java/org/openecomp/policy/common/logging/flexlogger/PropertyUtil.java
+++ b/common-logging/src/main/java/org/onap/policy/common/logging/flexlogger/PropertyUtil.java
@@ -1,6 +1,6 @@
/*-
* ============LICENSE_START=======================================================
- * ECOMP-Logging
+ * ONAP-Logging
* ================================================================================
* Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
* ================================================================================
@@ -18,7 +18,7 @@
* ============LICENSE_END=========================================================
*/
-package org.openecomp.policy.common.logging.flexlogger;
+package org.onap.policy.common.logging.flexlogger;
import java.io.File;
import java.io.FileInputStream;
diff --git a/common-logging/src/main/java/org/openecomp/policy/common/logging/flexlogger/SystemOutLogger.java b/common-logging/src/main/java/org/onap/policy/common/logging/flexlogger/SystemOutLogger.java
index 596914a2..f1acc042 100644
--- a/common-logging/src/main/java/org/openecomp/policy/common/logging/flexlogger/SystemOutLogger.java
+++ b/common-logging/src/main/java/org/onap/policy/common/logging/flexlogger/SystemOutLogger.java
@@ -1,6 +1,6 @@
/*-
* ============LICENSE_START=======================================================
- * ECOMP-Logging
+ * ONAP-Logging
* ================================================================================
* Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
* ================================================================================
@@ -18,13 +18,13 @@
* ============LICENSE_END=========================================================
*/
-package org.openecomp.policy.common.logging.flexlogger;
+package org.onap.policy.common.logging.flexlogger;
import java.io.Serializable;
import java.util.UUID;
-import org.openecomp.policy.common.logging.eelf.MessageCodes;
-import org.openecomp.policy.common.logging.eelf.PolicyLogger;
+import org.onap.policy.common.logging.eelf.MessageCodes;
+import org.onap.policy.common.logging.eelf.PolicyLogger;
import com.att.eelf.configuration.EELFLogger.Level;
/**
diff --git a/common-logging/src/main/java/org/openecomp/policy/common/logging/nsa/LoggingContext.java b/common-logging/src/main/java/org/onap/policy/common/logging/nsa/LoggingContext.java
index 56f6686a..0786febd 100644
--- a/common-logging/src/main/java/org/openecomp/policy/common/logging/nsa/LoggingContext.java
+++ b/common-logging/src/main/java/org/onap/policy/common/logging/nsa/LoggingContext.java
@@ -1,6 +1,6 @@
/*-
* ============LICENSE_START=======================================================
- * ECOMP-Logging
+ * ONAP-Logging
* ================================================================================
* Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
* ================================================================================
@@ -18,7 +18,7 @@
* ============LICENSE_END=========================================================
*/
-package org.openecomp.policy.common.logging.nsa;
+package org.onap.policy.common.logging.nsa;
/**
* An interface for providing data into the underlying logging context. Systems should use
diff --git a/common-logging/src/main/java/org/openecomp/policy/common/logging/nsa/LoggingContextFactory.java b/common-logging/src/main/java/org/onap/policy/common/logging/nsa/LoggingContextFactory.java
index b8fce10c..78fffefe 100644
--- a/common-logging/src/main/java/org/openecomp/policy/common/logging/nsa/LoggingContextFactory.java
+++ b/common-logging/src/main/java/org/onap/policy/common/logging/nsa/LoggingContextFactory.java
@@ -1,6 +1,6 @@
/*-
* ============LICENSE_START=======================================================
- * ECOMP-Logging
+ * ONAP-Logging
* ================================================================================
* Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
* ================================================================================
@@ -18,11 +18,11 @@
* ============LICENSE_END=========================================================
*/
-package org.openecomp.policy.common.logging.nsa;
+package org.onap.policy.common.logging.nsa;
-import org.openecomp.policy.common.logging.nsa.impl.SharedContext;
-import org.openecomp.policy.common.logging.nsa.impl.Slf4jLoggingContext;
+import org.onap.policy.common.logging.nsa.impl.SharedContext;
+import org.onap.policy.common.logging.nsa.impl.Slf4jLoggingContext;
/**
* A factory for setting up a LoggingContext
diff --git a/common-logging/src/main/java/org/openecomp/policy/common/logging/nsa/SharedLoggingContext.java b/common-logging/src/main/java/org/onap/policy/common/logging/nsa/SharedLoggingContext.java
index 2ecbcb0a..af0cc393 100644
--- a/common-logging/src/main/java/org/openecomp/policy/common/logging/nsa/SharedLoggingContext.java
+++ b/common-logging/src/main/java/org/onap/policy/common/logging/nsa/SharedLoggingContext.java
@@ -1,6 +1,6 @@
/*-
* ============LICENSE_START=======================================================
- * ECOMP-Logging
+ * ONAP-Logging
* ================================================================================
* Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
* ================================================================================
@@ -18,7 +18,7 @@
* ============LICENSE_END=========================================================
*/
-package org.openecomp.policy.common.logging.nsa;
+package org.onap.policy.common.logging.nsa;
/**
* A logging context must be thread-specific. Contexts that implement SharedLoggingContext
diff --git a/common-logging/src/main/java/org/openecomp/policy/common/logging/nsa/impl/SharedContext.java b/common-logging/src/main/java/org/onap/policy/common/logging/nsa/impl/SharedContext.java
index 96ffbf64..715edfab 100644
--- a/common-logging/src/main/java/org/openecomp/policy/common/logging/nsa/impl/SharedContext.java
+++ b/common-logging/src/main/java/org/onap/policy/common/logging/nsa/impl/SharedContext.java
@@ -1,6 +1,6 @@
/*-
* ============LICENSE_START=======================================================
- * ECOMP-Logging
+ * ONAP-Logging
* ================================================================================
* Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
* ================================================================================
@@ -18,13 +18,13 @@
* ============LICENSE_END=========================================================
*/
-package org.openecomp.policy.common.logging.nsa.impl;
+package org.onap.policy.common.logging.nsa.impl;
import java.util.HashMap;
import java.util.Map.Entry;
-import org.openecomp.policy.common.logging.nsa.LoggingContext;
-import org.openecomp.policy.common.logging.nsa.SharedLoggingContext;
+import org.onap.policy.common.logging.nsa.LoggingContext;
+import org.onap.policy.common.logging.nsa.SharedLoggingContext;
/**
* A shared logging context for SLF4J
diff --git a/common-logging/src/main/java/org/openecomp/policy/common/logging/nsa/impl/Slf4jLoggingContext.java b/common-logging/src/main/java/org/onap/policy/common/logging/nsa/impl/Slf4jLoggingContext.java
index de31af98..187b2954 100644
--- a/common-logging/src/main/java/org/openecomp/policy/common/logging/nsa/impl/Slf4jLoggingContext.java
+++ b/common-logging/src/main/java/org/onap/policy/common/logging/nsa/impl/Slf4jLoggingContext.java
@@ -1,6 +1,6 @@
/*-
* ============LICENSE_START=======================================================
- * ECOMP-Logging
+ * ONAP-Logging
* ================================================================================
* Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
* ================================================================================
@@ -18,11 +18,11 @@
* ============LICENSE_END=========================================================
*/
-package org.openecomp.policy.common.logging.nsa.impl;
+package org.onap.policy.common.logging.nsa.impl;
import org.slf4j.MDC;
-import org.openecomp.policy.common.logging.nsa.LoggingContext;
+import org.onap.policy.common.logging.nsa.LoggingContext;
/**
* A logging context for SLF4J
diff --git a/common-logging/src/main/java/org/openecomp/policy/common/logging/nsa/package-info.java b/common-logging/src/main/java/org/onap/policy/common/logging/nsa/package-info.java
index e1ef710b..6f58bb0f 100644
--- a/common-logging/src/main/java/org/openecomp/policy/common/logging/nsa/package-info.java
+++ b/common-logging/src/main/java/org/onap/policy/common/logging/nsa/package-info.java
@@ -1,6 +1,6 @@
/*-
* ============LICENSE_START=======================================================
- * ECOMP-Logging
+ * ONAP-Logging
* ================================================================================
* Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
* ================================================================================
@@ -23,5 +23,5 @@
* implementation based on the SLF4J/Log4j "MDC" (Mapped Diagnostic Context) feature.
*
*/
-package org.openecomp.policy.common.logging.nsa;
+package org.onap.policy.common.logging.nsa;
diff --git a/common-logging/src/main/resources/org/openecomp/policy/common/logging/eelf/Resources.properties b/common-logging/src/main/resources/org/onap/policy/common/logging/eelf/Resources.properties
index c79061b4..b41dbb26 100644
--- a/common-logging/src/main/resources/org/openecomp/policy/common/logging/eelf/Resources.properties
+++ b/common-logging/src/main/resources/org/onap/policy/common/logging/eelf/Resources.properties
@@ -1,6 +1,6 @@
###
# ============LICENSE_START=======================================================
-# ECOMP-Logging
+# ONAP-Logging
# ================================================================================
# Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
# ================================================================================
diff --git a/common-logging/src/main/java/org/openecomp/policy/common/logging/ECOMPLoggingContext.java b/common-logging/src/main/java/org/onap/policy/common/logging/ONAPLoggingContext.java
index 606e872d..bbaf2e0e 100644
--- a/common-logging/src/main/java/org/openecomp/policy/common/logging/ECOMPLoggingContext.java
+++ b/common-logging/src/main/java/org/onap/policy/common/logging/ONAPLoggingContext.java
@@ -1,6 +1,6 @@
/*-
* ============LICENSE_START=======================================================
- * ECOMP-Logging
+ * ONAP-Logging
* ================================================================================
* Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
* ================================================================================
@@ -18,11 +18,11 @@
* ============LICENSE_END=========================================================
*/
-package org.openecomp.policy.common.logging;
+package org.onap.policy.common.logging;
-//import static org.openecomp.policy.common.logging.eelf.Configuration.TRANSACTION_BEGIN_TIME_STAMP;
-//import static org.openecomp.policy.common.logging.eelf.Configuration.TRANSACTION_ELAPSED_TIME;
-//import static org.openecomp.policy.common.logging.eelf.Configuration.TRANSACTION_END_TIME_STAMP;
+//import static org.onap.policy.common.logging.eelf.Configuration.TRANSACTION_BEGIN_TIME_STAMP;
+//import static org.onap.policy.common.logging.eelf.Configuration.TRANSACTION_ELAPSED_TIME;
+//import static org.onap.policy.common.logging.eelf.Configuration.TRANSACTION_END_TIME_STAMP;
import java.text.SimpleDateFormat;
import java.time.Duration;
@@ -30,11 +30,11 @@ import java.time.Instant;
import java.util.Date;
import org.slf4j.MDC;
-import org.openecomp.policy.common.logging.nsa.LoggingContextFactory;
-import org.openecomp.policy.common.logging.nsa.SharedLoggingContext;
+import org.onap.policy.common.logging.nsa.LoggingContextFactory;
+import org.onap.policy.common.logging.nsa.SharedLoggingContext;
/**
* A facade over the org.openecomp.policy.common.logging.nsa.SharedLoggingContext interface/implementation that makes it
* more convenient to use. SharedLoggingContext builds on the SLF4J/log4j Mapped Diagnostic Context (MDC)
* feature, which provides a hashmap-based context for data items that need to be logged, where the
* hashmap is kept in ThreadLocal storage. The data items can be referenced in the log4j configuration
@@ -47,20 +47,20 @@ import org.openecomp.policy.common.logging.nsa.SharedLoggingContext;
*
* The notable functionality the SharedLoggingContext adds over MDC is that it maintains its own copy
* of the MDC data items in a hashmap (not in ThreadLocal storage), which allows more control of the data.
* The ECOMPLoggingContext constructor that takes another ECOMPLoggingContext object as a parameter makes
* use of this feature. For example if there is a thread pulling requests from a queue for processing, it
* can keep a base logging context with data that is common to all requests, and for each request, create a
* new logging context with that base context as a parameter; this will create a new logging context with
* those initial values and none of the request-specific values from the previous request such as a request ID.
* The setter methods in this class set corresponding items in the SharedLoggingContext/MDC hashmaps.
* These items correspond to the fields defined in the "ECOMP platform application logging guidelines"
* document. In addition, there is a pair of convenience functions, transactionStarted() and
* transactionEnded(), that can be called at the beginning and end of transaction processing to calculate
* the duration of the transaction and record that value in the "timer" item.
*
*/
-public class ECOMPLoggingContext {
+public class ONAPLoggingContext {
private static final String REQUEST_ID = "requestId";
private static final String SERVICE_INSTANCE_ID = "serviceInstanceId";
@@ -93,14 +93,14 @@ public class ECOMPLoggingContext {
private Instant metricStartTime;
/**
* Create a new ECOMPLoggingContext with no base context.
*/
- public ECOMPLoggingContext() {
+ public ONAPLoggingContext() {
context = (SharedLoggingContext) loggingContextBuilder.forSharing().build();
}
/**
* Create a new ECOMPLoggingContext initially populated with the values
* in the given base context. This can be used for example in a servlet
* where each incoming request may be processed by a separate thread, but
* there may be some logging data items that will be unchanging and common
@@ -109,7 +109,7 @@ public class ECOMPLoggingContext {
* base context to populate the common data in the new one.
* @param baseContext
*/
- public ECOMPLoggingContext(ECOMPLoggingContext baseContext) {
+ public ONAPLoggingContext(ONAPLoggingContext baseContext) {
context = (SharedLoggingContext) loggingContextBuilder.forSharing().build();
// a logging context could be passed into a thread (e.g. one that is servicing a queue)
// that already had a logging context established, so the MDC hashmap could contain
@@ -30,11 +30,11 @@ import java.time.Instant;
/**
- * A facade over the org.openecomp.policy.common.logging.nsa.SharedLoggingContext interface/implementation that makes it
+ * A facade over the org.onap.policy.common.logging.nsa.SharedLoggingContext interface/implementation that makes it
* more convenient to use. SharedLoggingContext builds on the SLF4J/log4j Mapped Diagnostic Context (MDC)
* feature, which provides a hashmap-based context for data items that need to be logged, where the
@@ -47,20 +47,20 @@ import org.openecomp.policy.common.logging.nsa.SharedLoggingContext;
* The notable functionality the SharedLoggingContext adds over MDC is that it maintains its own copy
* of the MDC data items in a hashmap (not in ThreadLocal storage), which allows more control of the data.
- * The ECOMPLoggingContext constructor that takes another ECOMPLoggingContext object as a parameter makes
+ * The ONAPLoggingContext constructor that takes another ONAPLoggingContext object as a parameter makes
* use of this feature. For example if there is a thread pulling requests from a queue for processing, it
* can keep a base logging context with data that is common to all requests, and for each request, create a
@@ -47,20 +47,20 @@ import org.openecomp.policy.common.logging.nsa.SharedLoggingContext;
* those initial values and none of the request-specific values from the previous request such as a request ID.
* The setter methods in this class set corresponding items in the SharedLoggingContext/MDC hashmaps.
- * These items correspond to the fields defined in the "ECOMP platform application logging guidelines"
+ * These items correspond to the fields defined in the "ONAP platform application logging guidelines"
* document. In addition, there is a pair of convenience functions, transactionStarted() and
* transactionEnded(), that can be called at the beginning and end of transaction processing to calculate
@@ -93,14 +93,14 @@ public class ECOMPLoggingContext {
private Instant metricStartTime;
/**
- * Create a new ECOMPLoggingContext with no base context.
+ * Create a new ONAPLoggingContext with no base context.
*/
@@ -93,14 +93,14 @@ public class ECOMPLoggingContext {
}
/**
- * Create a new ECOMPLoggingContext initially populated with the values
+ * Create a new ONAPLoggingContext initially populated with the values
* in the given base context. This can be used for example in a servlet
* where each incoming request may be processed by a separate thread, but